# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from powergate.admin.v1 import admin_pb2 as powergate_dot_admin_dot_v1_dot_admin__pb2


class AdminServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.NewAddress = channel.unary_unary(
                '/powergate.admin.v1.AdminService/NewAddress',
                request_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.NewAddressRequest.SerializeToString,
                response_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.NewAddressResponse.FromString,
                )
        self.Addresses = channel.unary_unary(
                '/powergate.admin.v1.AdminService/Addresses',
                request_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.AddressesRequest.SerializeToString,
                response_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.AddressesResponse.FromString,
                )
        self.SendFil = channel.unary_unary(
                '/powergate.admin.v1.AdminService/SendFil',
                request_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.SendFilRequest.SerializeToString,
                response_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.SendFilResponse.FromString,
                )
        self.CreateUser = channel.unary_unary(
                '/powergate.admin.v1.AdminService/CreateUser',
                request_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.CreateUserRequest.SerializeToString,
                response_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.CreateUserResponse.FromString,
                )
        self.RegenerateAuth = channel.unary_unary(
                '/powergate.admin.v1.AdminService/RegenerateAuth',
                request_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.RegenerateAuthRequest.SerializeToString,
                response_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.RegenerateAuthResponse.FromString,
                )
        self.Users = channel.unary_unary(
                '/powergate.admin.v1.AdminService/Users',
                request_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.UsersRequest.SerializeToString,
                response_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.UsersResponse.FromString,
                )
        self.StorageInfo = channel.unary_unary(
                '/powergate.admin.v1.AdminService/StorageInfo',
                request_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.StorageInfoRequest.SerializeToString,
                response_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.StorageInfoResponse.FromString,
                )
        self.ListStorageInfo = channel.unary_unary(
                '/powergate.admin.v1.AdminService/ListStorageInfo',
                request_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.ListStorageInfoRequest.SerializeToString,
                response_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.ListStorageInfoResponse.FromString,
                )
        self.ListStorageJobs = channel.unary_unary(
                '/powergate.admin.v1.AdminService/ListStorageJobs',
                request_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.ListStorageJobsRequest.SerializeToString,
                response_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.ListStorageJobsResponse.FromString,
                )
        self.StorageJobsSummary = channel.unary_unary(
                '/powergate.admin.v1.AdminService/StorageJobsSummary',
                request_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.StorageJobsSummaryRequest.SerializeToString,
                response_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.StorageJobsSummaryResponse.FromString,
                )
        self.GetUpdatedStorageDealRecordsSince = channel.unary_unary(
                '/powergate.admin.v1.AdminService/GetUpdatedStorageDealRecordsSince',
                request_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.GetUpdatedStorageDealRecordsSinceRequest.SerializeToString,
                response_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.GetUpdatedStorageDealRecordsSinceResponse.FromString,
                )
        self.GetUpdatedRetrievalRecordsSince = channel.unary_unary(
                '/powergate.admin.v1.AdminService/GetUpdatedRetrievalRecordsSince',
                request_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.GetUpdatedRetrievalRecordsSinceRequest.SerializeToString,
                response_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.GetUpdatedRetrievalRecordsSinceResponse.FromString,
                )
        self.GCStaged = channel.unary_unary(
                '/powergate.admin.v1.AdminService/GCStaged',
                request_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.GCStagedRequest.SerializeToString,
                response_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.GCStagedResponse.FromString,
                )
        self.PinnedCids = channel.unary_unary(
                '/powergate.admin.v1.AdminService/PinnedCids',
                request_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.PinnedCidsRequest.SerializeToString,
                response_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.PinnedCidsResponse.FromString,
                )
        self.GetMiners = channel.unary_unary(
                '/powergate.admin.v1.AdminService/GetMiners',
                request_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.GetMinersRequest.SerializeToString,
                response_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.GetMinersResponse.FromString,
                )
        self.GetMinerInfo = channel.unary_unary(
                '/powergate.admin.v1.AdminService/GetMinerInfo',
                request_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.GetMinerInfoRequest.SerializeToString,
                response_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.GetMinerInfoResponse.FromString,
                )


class AdminServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def NewAddress(self, request, context):
        """Wallet
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Addresses(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendFil(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateUser(self, request, context):
        """Users
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegenerateAuth(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Users(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StorageInfo(self, request, context):
        """Storage Info
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListStorageInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListStorageJobs(self, request, context):
        """Storage Jobs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StorageJobsSummary(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUpdatedStorageDealRecordsSince(self, request, context):
        """Updated Records
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUpdatedRetrievalRecordsSince(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GCStaged(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PinnedCids(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMiners(self, request, context):
        """Indices
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMinerInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AdminServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'NewAddress': grpc.unary_unary_rpc_method_handler(
                    servicer.NewAddress,
                    request_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.NewAddressRequest.FromString,
                    response_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.NewAddressResponse.SerializeToString,
            ),
            'Addresses': grpc.unary_unary_rpc_method_handler(
                    servicer.Addresses,
                    request_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.AddressesRequest.FromString,
                    response_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.AddressesResponse.SerializeToString,
            ),
            'SendFil': grpc.unary_unary_rpc_method_handler(
                    servicer.SendFil,
                    request_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.SendFilRequest.FromString,
                    response_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.SendFilResponse.SerializeToString,
            ),
            'CreateUser': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateUser,
                    request_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.CreateUserRequest.FromString,
                    response_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.CreateUserResponse.SerializeToString,
            ),
            'RegenerateAuth': grpc.unary_unary_rpc_method_handler(
                    servicer.RegenerateAuth,
                    request_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.RegenerateAuthRequest.FromString,
                    response_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.RegenerateAuthResponse.SerializeToString,
            ),
            'Users': grpc.unary_unary_rpc_method_handler(
                    servicer.Users,
                    request_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.UsersRequest.FromString,
                    response_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.UsersResponse.SerializeToString,
            ),
            'StorageInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.StorageInfo,
                    request_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.StorageInfoRequest.FromString,
                    response_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.StorageInfoResponse.SerializeToString,
            ),
            'ListStorageInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.ListStorageInfo,
                    request_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.ListStorageInfoRequest.FromString,
                    response_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.ListStorageInfoResponse.SerializeToString,
            ),
            'ListStorageJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListStorageJobs,
                    request_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.ListStorageJobsRequest.FromString,
                    response_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.ListStorageJobsResponse.SerializeToString,
            ),
            'StorageJobsSummary': grpc.unary_unary_rpc_method_handler(
                    servicer.StorageJobsSummary,
                    request_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.StorageJobsSummaryRequest.FromString,
                    response_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.StorageJobsSummaryResponse.SerializeToString,
            ),
            'GetUpdatedStorageDealRecordsSince': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUpdatedStorageDealRecordsSince,
                    request_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.GetUpdatedStorageDealRecordsSinceRequest.FromString,
                    response_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.GetUpdatedStorageDealRecordsSinceResponse.SerializeToString,
            ),
            'GetUpdatedRetrievalRecordsSince': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUpdatedRetrievalRecordsSince,
                    request_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.GetUpdatedRetrievalRecordsSinceRequest.FromString,
                    response_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.GetUpdatedRetrievalRecordsSinceResponse.SerializeToString,
            ),
            'GCStaged': grpc.unary_unary_rpc_method_handler(
                    servicer.GCStaged,
                    request_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.GCStagedRequest.FromString,
                    response_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.GCStagedResponse.SerializeToString,
            ),
            'PinnedCids': grpc.unary_unary_rpc_method_handler(
                    servicer.PinnedCids,
                    request_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.PinnedCidsRequest.FromString,
                    response_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.PinnedCidsResponse.SerializeToString,
            ),
            'GetMiners': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMiners,
                    request_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.GetMinersRequest.FromString,
                    response_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.GetMinersResponse.SerializeToString,
            ),
            'GetMinerInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMinerInfo,
                    request_deserializer=powergate_dot_admin_dot_v1_dot_admin__pb2.GetMinerInfoRequest.FromString,
                    response_serializer=powergate_dot_admin_dot_v1_dot_admin__pb2.GetMinerInfoResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'powergate.admin.v1.AdminService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AdminService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def NewAddress(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.admin.v1.AdminService/NewAddress',
            powergate_dot_admin_dot_v1_dot_admin__pb2.NewAddressRequest.SerializeToString,
            powergate_dot_admin_dot_v1_dot_admin__pb2.NewAddressResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Addresses(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.admin.v1.AdminService/Addresses',
            powergate_dot_admin_dot_v1_dot_admin__pb2.AddressesRequest.SerializeToString,
            powergate_dot_admin_dot_v1_dot_admin__pb2.AddressesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendFil(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.admin.v1.AdminService/SendFil',
            powergate_dot_admin_dot_v1_dot_admin__pb2.SendFilRequest.SerializeToString,
            powergate_dot_admin_dot_v1_dot_admin__pb2.SendFilResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.admin.v1.AdminService/CreateUser',
            powergate_dot_admin_dot_v1_dot_admin__pb2.CreateUserRequest.SerializeToString,
            powergate_dot_admin_dot_v1_dot_admin__pb2.CreateUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegenerateAuth(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.admin.v1.AdminService/RegenerateAuth',
            powergate_dot_admin_dot_v1_dot_admin__pb2.RegenerateAuthRequest.SerializeToString,
            powergate_dot_admin_dot_v1_dot_admin__pb2.RegenerateAuthResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Users(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.admin.v1.AdminService/Users',
            powergate_dot_admin_dot_v1_dot_admin__pb2.UsersRequest.SerializeToString,
            powergate_dot_admin_dot_v1_dot_admin__pb2.UsersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StorageInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.admin.v1.AdminService/StorageInfo',
            powergate_dot_admin_dot_v1_dot_admin__pb2.StorageInfoRequest.SerializeToString,
            powergate_dot_admin_dot_v1_dot_admin__pb2.StorageInfoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListStorageInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.admin.v1.AdminService/ListStorageInfo',
            powergate_dot_admin_dot_v1_dot_admin__pb2.ListStorageInfoRequest.SerializeToString,
            powergate_dot_admin_dot_v1_dot_admin__pb2.ListStorageInfoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListStorageJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.admin.v1.AdminService/ListStorageJobs',
            powergate_dot_admin_dot_v1_dot_admin__pb2.ListStorageJobsRequest.SerializeToString,
            powergate_dot_admin_dot_v1_dot_admin__pb2.ListStorageJobsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StorageJobsSummary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.admin.v1.AdminService/StorageJobsSummary',
            powergate_dot_admin_dot_v1_dot_admin__pb2.StorageJobsSummaryRequest.SerializeToString,
            powergate_dot_admin_dot_v1_dot_admin__pb2.StorageJobsSummaryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUpdatedStorageDealRecordsSince(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.admin.v1.AdminService/GetUpdatedStorageDealRecordsSince',
            powergate_dot_admin_dot_v1_dot_admin__pb2.GetUpdatedStorageDealRecordsSinceRequest.SerializeToString,
            powergate_dot_admin_dot_v1_dot_admin__pb2.GetUpdatedStorageDealRecordsSinceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUpdatedRetrievalRecordsSince(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.admin.v1.AdminService/GetUpdatedRetrievalRecordsSince',
            powergate_dot_admin_dot_v1_dot_admin__pb2.GetUpdatedRetrievalRecordsSinceRequest.SerializeToString,
            powergate_dot_admin_dot_v1_dot_admin__pb2.GetUpdatedRetrievalRecordsSinceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GCStaged(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.admin.v1.AdminService/GCStaged',
            powergate_dot_admin_dot_v1_dot_admin__pb2.GCStagedRequest.SerializeToString,
            powergate_dot_admin_dot_v1_dot_admin__pb2.GCStagedResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PinnedCids(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.admin.v1.AdminService/PinnedCids',
            powergate_dot_admin_dot_v1_dot_admin__pb2.PinnedCidsRequest.SerializeToString,
            powergate_dot_admin_dot_v1_dot_admin__pb2.PinnedCidsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMiners(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.admin.v1.AdminService/GetMiners',
            powergate_dot_admin_dot_v1_dot_admin__pb2.GetMinersRequest.SerializeToString,
            powergate_dot_admin_dot_v1_dot_admin__pb2.GetMinersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMinerInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.admin.v1.AdminService/GetMinerInfo',
            powergate_dot_admin_dot_v1_dot_admin__pb2.GetMinerInfoRequest.SerializeToString,
            powergate_dot_admin_dot_v1_dot_admin__pb2.GetMinerInfoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: powergate/admin/v1/admin.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from powergate.user.v1 import user_pb2 as powergate_dot_user_dot_v1_dot_user__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='powergate/admin/v1/admin.proto',
  package='powergate.admin.v1',
  syntax='proto3',
  serialized_options=b'ZDgithub.com/textileio/powergate/v2/api/gen/powergate/admin/v1;adminPb',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1epowergate/admin/v1/admin.proto\x12\x12powergate.admin.v1\x1a\x1cpowergate/user/v1/user.proto\x1a\x1fgoogle/protobuf/timestamp.proto\")\n\x11NewAddressRequest\x12\x14\n\x0c\x61\x64\x64ress_type\x18\x01 \x01(\t\"%\n\x12NewAddressResponse\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"\x12\n\x10\x41\x64\x64ressesRequest\"&\n\x11\x41\x64\x64ressesResponse\x12\x11\n\taddresses\x18\x01 \x03(\t\":\n\x0eSendFilRequest\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\n\n\x02to\x18\x02 \x01(\t\x12\x0e\n\x06\x61mount\x18\x03 \x01(\t\"\x1e\n\x0fSendFilResponse\x12\x0b\n\x03\x63id\x18\x01 \x01(\t\"!\n\x04User\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\"\x13\n\x11\x43reateUserRequest\"<\n\x12\x43reateUserResponse\x12&\n\x04user\x18\x01 \x01(\x0b\x32\x18.powergate.admin.v1.User\"&\n\x15RegenerateAuthRequest\x12\r\n\x05token\x18\x01 \x01(\t\"+\n\x16RegenerateAuthResponse\x12\x11\n\tnew_token\x18\x01 \x01(\t\"\x0e\n\x0cUsersRequest\"8\n\rUsersResponse\x12\'\n\x05users\x18\x01 \x03(\x0b\x32\x18.powergate.admin.v1.User\"2\n\x12StorageInfoRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0b\n\x03\x63id\x18\x02 \x01(\t\"K\n\x13StorageInfoResponse\x12\x34\n\x0cstorage_info\x18\x01 \x01(\x0b\x32\x1e.powergate.user.v1.StorageInfo\"8\n\x16ListStorageInfoRequest\x12\x10\n\x08user_ids\x18\x01 \x03(\t\x12\x0c\n\x04\x63ids\x18\x02 \x03(\t\"O\n\x17ListStorageInfoResponse\x12\x34\n\x0cstorage_info\x18\x01 \x03(\x0b\x32\x1e.powergate.user.v1.StorageInfo\"\xb9\x01\n\x16ListStorageJobsRequest\x12\x16\n\x0euser_id_filter\x18\x01 \x01(\t\x12\x12\n\ncid_filter\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x04\x12\x11\n\tascending\x18\x04 \x01(\x08\x12\x17\n\x0fnext_page_token\x18\x05 \x01(\t\x12\x38\n\x08selector\x18\x06 \x01(\x0e\x32&.powergate.user.v1.StorageJobsSelector\"u\n\x17ListStorageJobsResponse\x12\x33\n\x0cstorage_jobs\x18\x01 \x03(\x0b\x32\x1d.powergate.user.v1.StorageJob\x12\x0c\n\x04more\x18\x02 \x01(\x08\x12\x17\n\x0fnext_page_token\x18\x03 \x01(\t\"9\n\x19StorageJobsSummaryRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0b\n\x03\x63id\x18\x02 \x01(\t\"u\n\x1aStorageJobsSummaryResponse\x12\x1b\n\x13queued_storage_jobs\x18\x01 \x03(\t\x12\x1e\n\x16\x65xecuting_storage_jobs\x18\x02 \x03(\t\x12\x1a\n\x12\x66inal_storage_jobs\x18\x03 \x03(\t\"\x11\n\x0fGCStagedRequest\")\n\x10GCStagedResponse\x12\x15\n\runpinned_cids\x18\x01 \x03(\t\"\x13\n\x11PinnedCidsRequest\"C\n\x12PinnedCidsResponse\x12-\n\x04\x63ids\x18\x01 \x03(\x0b\x32\x1f.powergate.admin.v1.HSPinnedCid\"N\n\x0bHSPinnedCid\x12\x0b\n\x03\x63id\x18\x01 \x01(\t\x12\x32\n\x05users\x18\x02 \x03(\x0b\x32#.powergate.admin.v1.HSPinnedCidUser\"F\n\x0fHSPinnedCidUser\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0e\n\x06staged\x18\x02 \x01(\x08\x12\x12\n\ncreated_at\x18\x03 \x01(\x03\"d\n(GetUpdatedStorageDealRecordsSinceRequest\x12)\n\x05since\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05limit\x18\x02 \x01(\x05\"b\n)GetUpdatedStorageDealRecordsSinceResponse\x12\x35\n\x07records\x18\x01 \x03(\x0b\x32$.powergate.user.v1.StorageDealRecord\"b\n&GetUpdatedRetrievalRecordsSinceRequest\x12)\n\x05since\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05limit\x18\x02 \x01(\x05\"b\n\'GetUpdatedRetrievalRecordsSinceResponse\x12\x37\n\x07records\x18\x01 \x03(\x0b\x32&.powergate.user.v1.RetrievalDealRecord\"&\n\x10GetMinersRequest\x12\x12\n\nwith_power\x18\x01 \x01(\x08\"F\n\x11GetMinersResponse\x12\x31\n\x06miners\x18\x01 \x03(\x0b\x32!.powergate.admin.v1.FilecoinMiner\" \n\rFilecoinMiner\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"%\n\x13GetMinerInfoRequest\x12\x0e\n\x06miners\x18\x01 \x03(\t\"J\n\x14GetMinerInfoResponse\x12\x32\n\x0bminers_info\x18\x01 \x03(\x0b\x32\x1d.powergate.admin.v1.MinerInfo\"\x80\x02\n\tMinerInfo\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x16\n\x0erelative_power\x18\x02 \x01(\x01\x12\x11\n\task_price\x18\x04 \x01(\t\x12\x1a\n\x12\x61sk_verified_price\x18\x05 \x01(\t\x12\x16\n\x0emin_piece_size\x18\x06 \x01(\x04\x12\x16\n\x0emax_piece_size\x18\x07 \x01(\x04\x12\x13\n\x0bsector_size\x18\x08 \x01(\x04\x12\x16\n\x0esectors_active\x18\t \x01(\x04\x12\x14\n\x0csectors_live\x18\n \x01(\x04\x12\x16\n\x0esectors_faulty\x18\x0b \x01(\x04\x12\x10\n\x08location\x18\x0c \x01(\t2\xab\r\n\x0c\x41\x64minService\x12]\n\nNewAddress\x12%.powergate.admin.v1.NewAddressRequest\x1a&.powergate.admin.v1.NewAddressResponse\"\x00\x12Z\n\tAddresses\x12$.powergate.admin.v1.AddressesRequest\x1a%.powergate.admin.v1.AddressesResponse\"\x00\x12T\n\x07SendFil\x12\".powergate.admin.v1.SendFilRequest\x1a#.powergate.admin.v1.SendFilResponse\"\x00\x12]\n\nCreateUser\x12%.powergate.admin.v1.CreateUserRequest\x1a&.powergate.admin.v1.CreateUserResponse\"\x00\x12i\n\x0eRegenerateAuth\x12).powergate.admin.v1.RegenerateAuthRequest\x1a*.powergate.admin.v1.RegenerateAuthResponse\"\x00\x12N\n\x05Users\x12 .powergate.admin.v1.UsersRequest\x1a!.powergate.admin.v1.UsersResponse\"\x00\x12`\n\x0bStorageInfo\x12&.powergate.admin.v1.StorageInfoRequest\x1a\'.powergate.admin.v1.StorageInfoResponse\"\x00\x12l\n\x0fListStorageInfo\x12*.powergate.admin.v1.ListStorageInfoRequest\x1a+.powergate.admin.v1.ListStorageInfoResponse\"\x00\x12l\n\x0fListStorageJobs\x12*.powergate.admin.v1.ListStorageJobsRequest\x1a+.powergate.admin.v1.ListStorageJobsResponse\"\x00\x12u\n\x12StorageJobsSummary\x12-.powergate.admin.v1.StorageJobsSummaryRequest\x1a..powergate.admin.v1.StorageJobsSummaryResponse\"\x00\x12\xa2\x01\n!GetUpdatedStorageDealRecordsSince\x12<.powergate.admin.v1.GetUpdatedStorageDealRecordsSinceRequest\x1a=.powergate.admin.v1.GetUpdatedStorageDealRecordsSinceResponse\"\x00\x12\x9c\x01\n\x1fGetUpdatedRetrievalRecordsSince\x12:.powergate.admin.v1.GetUpdatedRetrievalRecordsSinceRequest\x1a;.powergate.admin.v1.GetUpdatedRetrievalRecordsSinceResponse\"\x00\x12W\n\x08GCStaged\x12#.powergate.admin.v1.GCStagedRequest\x1a$.powergate.admin.v1.GCStagedResponse\"\x00\x12]\n\nPinnedCids\x12%.powergate.admin.v1.PinnedCidsRequest\x1a&.powergate.admin.v1.PinnedCidsResponse\"\x00\x12Z\n\tGetMiners\x12$.powergate.admin.v1.GetMinersRequest\x1a%.powergate.admin.v1.GetMinersResponse\"\x00\x12\x63\n\x0cGetMinerInfo\x12\'.powergate.admin.v1.GetMinerInfoRequest\x1a(.powergate.admin.v1.GetMinerInfoResponse\"\x00\x42\x46ZDgithub.com/textileio/powergate/v2/api/gen/powergate/admin/v1;adminPbb\x06proto3'
  ,
  dependencies=[powergate_dot_user_dot_v1_dot_user__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_NEWADDRESSREQUEST = _descriptor.Descriptor(
  name='NewAddressRequest',
  full_name='powergate.admin.v1.NewAddressRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address_type', full_name='powergate.admin.v1.NewAddressRequest.address_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=117,
  serialized_end=158,
)


_NEWADDRESSRESPONSE = _descriptor.Descriptor(
  name='NewAddressResponse',
  full_name='powergate.admin.v1.NewAddressResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='powergate.admin.v1.NewAddressResponse.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=160,
  serialized_end=197,
)


_ADDRESSESREQUEST = _descriptor.Descriptor(
  name='AddressesRequest',
  full_name='powergate.admin.v1.AddressesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=199,
  serialized_end=217,
)


_ADDRESSESRESPONSE = _descriptor.Descriptor(
  name='AddressesResponse',
  full_name='powergate.admin.v1.AddressesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='addresses', full_name='powergate.admin.v1.AddressesResponse.addresses', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=219,
  serialized_end=257,
)


_SENDFILREQUEST = _descriptor.Descriptor(
  name='SendFilRequest',
  full_name='powergate.admin.v1.SendFilRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='from', full_name='powergate.admin.v1.SendFilRequest.from', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to', full_name='powergate.admin.v1.SendFilRequest.to', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='powergate.admin.v1.SendFilRequest.amount', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=259,
  serialized_end=317,
)


_SENDFILRESPONSE = _descriptor.Descriptor(
  name='SendFilResponse',
  full_name='powergate.admin.v1.SendFilResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cid', full_name='powergate.admin.v1.SendFilResponse.cid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=319,
  serialized_end=349,
)


_USER = _descriptor.Descriptor(
  name='User',
  full_name='powergate.admin.v1.User',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='powergate.admin.v1.User.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token', full_name='powergate.admin.v1.User.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=351,
  serialized_end=384,
)


_CREATEUSERREQUEST = _descriptor.Descriptor(
  name='CreateUserRequest',
  full_name='powergate.admin.v1.CreateUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=386,
  serialized_end=405,
)


_CREATEUSERRESPONSE = _descriptor.Descriptor(
  name='CreateUserResponse',
  full_name='powergate.admin.v1.CreateUserResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='powergate.admin.v1.CreateUserResponse.user', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=407,
  serialized_end=467,
)


_REGENERATEAUTHREQUEST = _descriptor.Descriptor(
  name='RegenerateAuthRequest',
  full_name='powergate.admin.v1.RegenerateAuthRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='powergate.admin.v1.RegenerateAuthRequest.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=469,
  serialized_end=507,
)


_REGENERATEAUTHRESPONSE = _descriptor.Descriptor(
  name='RegenerateAuthResponse',
  full_name='powergate.admin.v1.RegenerateAuthResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='new_token', full_name='powergate.admin.v1.RegenerateAuthResponse.new_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=509,
  serialized_end=552,
)


_USERSREQUEST = _descriptor.Descriptor(
  name='UsersRequest',
  full_name='powergate.admin.v1.UsersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=554,
  serialized_end=568,
)


_USERSRESPONSE = _descriptor.Descriptor(
  name='UsersResponse',
  full_name='powergate.admin.v1.UsersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='users', full_name='powergate.admin.v1.UsersResponse.users', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=570,
  serialized_end=626,
)


_STORAGEINFOREQUEST = _descriptor.Descriptor(
  name='StorageInfoRequest',
  full_name='powergate.admin.v1.StorageInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='powergate.admin.v1.StorageInfoRequest.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cid', full_name='powergate.admin.v1.StorageInfoRequest.cid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=628,
  serialized_end=678,
)


_STORAGEINFORESPONSE = _descriptor.Descriptor(
  name='StorageInfoResponse',
  full_name='powergate.admin.v1.StorageInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage_info', full_name='powergate.admin.v1.StorageInfoResponse.storage_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=680,
  serialized_end=755,
)


_LISTSTORAGEINFOREQUEST = _descriptor.Descriptor(
  name='ListStorageInfoRequest',
  full_name='powergate.admin.v1.ListStorageInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_ids', full_name='powergate.admin.v1.ListStorageInfoRequest.user_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cids', full_name='powergate.admin.v1.ListStorageInfoRequest.cids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=757,
  serialized_end=813,
)


_LISTSTORAGEINFORESPONSE = _descriptor.Descriptor(
  name='ListStorageInfoResponse',
  full_name='powergate.admin.v1.ListStorageInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage_info', full_name='powergate.admin.v1.ListStorageInfoResponse.storage_info', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=815,
  serialized_end=894,
)


_LISTSTORAGEJOBSREQUEST = _descriptor.Descriptor(
  name='ListStorageJobsRequest',
  full_name='powergate.admin.v1.ListStorageJobsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id_filter', full_name='powergate.admin.v1.ListStorageJobsRequest.user_id_filter', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cid_filter', full_name='powergate.admin.v1.ListStorageJobsRequest.cid_filter', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='powergate.admin.v1.ListStorageJobsRequest.limit', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ascending', full_name='powergate.admin.v1.ListStorageJobsRequest.ascending', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='powergate.admin.v1.ListStorageJobsRequest.next_page_token', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selector', full_name='powergate.admin.v1.ListStorageJobsRequest.selector', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=897,
  serialized_end=1082,
)


_LISTSTORAGEJOBSRESPONSE = _descriptor.Descriptor(
  name='ListStorageJobsResponse',
  full_name='powergate.admin.v1.ListStorageJobsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage_jobs', full_name='powergate.admin.v1.ListStorageJobsResponse.storage_jobs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='more', full_name='powergate.admin.v1.ListStorageJobsResponse.more', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='powergate.admin.v1.ListStorageJobsResponse.next_page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1084,
  serialized_end=1201,
)


_STORAGEJOBSSUMMARYREQUEST = _descriptor.Descriptor(
  name='StorageJobsSummaryRequest',
  full_name='powergate.admin.v1.StorageJobsSummaryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='powergate.admin.v1.StorageJobsSummaryRequest.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cid', full_name='powergate.admin.v1.StorageJobsSummaryRequest.cid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1203,
  serialized_end=1260,
)


_STORAGEJOBSSUMMARYRESPONSE = _descriptor.Descriptor(
  name='StorageJobsSummaryResponse',
  full_name='powergate.admin.v1.StorageJobsSummaryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='queued_storage_jobs', full_name='powergate.admin.v1.StorageJobsSummaryResponse.queued_storage_jobs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='executing_storage_jobs', full_name='powergate.admin.v1.StorageJobsSummaryResponse.executing_storage_jobs', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='final_storage_jobs', full_name='powergate.admin.v1.StorageJobsSummaryResponse.final_storage_jobs', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1262,
  serialized_end=1379,
)


_GCSTAGEDREQUEST = _descriptor.Descriptor(
  name='GCStagedRequest',
  full_name='powergate.admin.v1.GCStagedRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1381,
  serialized_end=1398,
)


_GCSTAGEDRESPONSE = _descriptor.Descriptor(
  name='GCStagedResponse',
  full_name='powergate.admin.v1.GCStagedResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='unpinned_cids', full_name='powergate.admin.v1.GCStagedResponse.unpinned_cids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1400,
  serialized_end=1441,
)


_PINNEDCIDSREQUEST = _descriptor.Descriptor(
  name='PinnedCidsRequest',
  full_name='powergate.admin.v1.PinnedCidsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1443,
  serialized_end=1462,
)


_PINNEDCIDSRESPONSE = _descriptor.Descriptor(
  name='PinnedCidsResponse',
  full_name='powergate.admin.v1.PinnedCidsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cids', full_name='powergate.admin.v1.PinnedCidsResponse.cids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1464,
  serialized_end=1531,
)


_HSPINNEDCID = _descriptor.Descriptor(
  name='HSPinnedCid',
  full_name='powergate.admin.v1.HSPinnedCid',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cid', full_name='powergate.admin.v1.HSPinnedCid.cid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='users', full_name='powergate.admin.v1.HSPinnedCid.users', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1533,
  serialized_end=1611,
)


_HSPINNEDCIDUSER = _descriptor.Descriptor(
  name='HSPinnedCidUser',
  full_name='powergate.admin.v1.HSPinnedCidUser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='powergate.admin.v1.HSPinnedCidUser.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='staged', full_name='powergate.admin.v1.HSPinnedCidUser.staged', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='powergate.admin.v1.HSPinnedCidUser.created_at', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1613,
  serialized_end=1683,
)


_GETUPDATEDSTORAGEDEALRECORDSSINCEREQUEST = _descriptor.Descriptor(
  name='GetUpdatedStorageDealRecordsSinceRequest',
  full_name='powergate.admin.v1.GetUpdatedStorageDealRecordsSinceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='since', full_name='powergate.admin.v1.GetUpdatedStorageDealRecordsSinceRequest.since', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='powergate.admin.v1.GetUpdatedStorageDealRecordsSinceRequest.limit', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1685,
  serialized_end=1785,
)


_GETUPDATEDSTORAGEDEALRECORDSSINCERESPONSE = _descriptor.Descriptor(
  name='GetUpdatedStorageDealRecordsSinceResponse',
  full_name='powergate.admin.v1.GetUpdatedStorageDealRecordsSinceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='records', full_name='powergate.admin.v1.GetUpdatedStorageDealRecordsSinceResponse.records', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1787,
  serialized_end=1885,
)


_GETUPDATEDRETRIEVALRECORDSSINCEREQUEST = _descriptor.Descriptor(
  name='GetUpdatedRetrievalRecordsSinceRequest',
  full_name='powergate.admin.v1.GetUpdatedRetrievalRecordsSinceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='since', full_name='powergate.admin.v1.GetUpdatedRetrievalRecordsSinceRequest.since', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='powergate.admin.v1.GetUpdatedRetrievalRecordsSinceRequest.limit', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1887,
  serialized_end=1985,
)


_GETUPDATEDRETRIEVALRECORDSSINCERESPONSE = _descriptor.Descriptor(
  name='GetUpdatedRetrievalRecordsSinceResponse',
  full_name='powergate.admin.v1.GetUpdatedRetrievalRecordsSinceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='records', full_name='powergate.admin.v1.GetUpdatedRetrievalRecordsSinceResponse.records', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1987,
  serialized_end=2085,
)


_GETMINERSREQUEST = _descriptor.Descriptor(
  name='GetMinersRequest',
  full_name='powergate.admin.v1.GetMinersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='with_power', full_name='powergate.admin.v1.GetMinersRequest.with_power', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2087,
  serialized_end=2125,
)


_GETMINERSRESPONSE = _descriptor.Descriptor(
  name='GetMinersResponse',
  full_name='powergate.admin.v1.GetMinersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='miners', full_name='powergate.admin.v1.GetMinersResponse.miners', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2127,
  serialized_end=2197,
)


_FILECOINMINER = _descriptor.Descriptor(
  name='FilecoinMiner',
  full_name='powergate.admin.v1.FilecoinMiner',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='powergate.admin.v1.FilecoinMiner.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2199,
  serialized_end=2231,
)


_GETMINERINFOREQUEST = _descriptor.Descriptor(
  name='GetMinerInfoRequest',
  full_name='powergate.admin.v1.GetMinerInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='miners', full_name='powergate.admin.v1.GetMinerInfoRequest.miners', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2233,
  serialized_end=2270,
)


_GETMINERINFORESPONSE = _descriptor.Descriptor(
  name='GetMinerInfoResponse',
  full_name='powergate.admin.v1.GetMinerInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='miners_info', full_name='powergate.admin.v1.GetMinerInfoResponse.miners_info', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2272,
  serialized_end=2346,
)


_MINERINFO = _descriptor.Descriptor(
  name='MinerInfo',
  full_name='powergate.admin.v1.MinerInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='powergate.admin.v1.MinerInfo.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relative_power', full_name='powergate.admin.v1.MinerInfo.relative_power', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ask_price', full_name='powergate.admin.v1.MinerInfo.ask_price', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ask_verified_price', full_name='powergate.admin.v1.MinerInfo.ask_verified_price', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_piece_size', full_name='powergate.admin.v1.MinerInfo.min_piece_size', index=4,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_piece_size', full_name='powergate.admin.v1.MinerInfo.max_piece_size', index=5,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sector_size', full_name='powergate.admin.v1.MinerInfo.sector_size', index=6,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sectors_active', full_name='powergate.admin.v1.MinerInfo.sectors_active', index=7,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sectors_live', full_name='powergate.admin.v1.MinerInfo.sectors_live', index=8,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sectors_faulty', full_name='powergate.admin.v1.MinerInfo.sectors_faulty', index=9,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='powergate.admin.v1.MinerInfo.location', index=10,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2349,
  serialized_end=2605,
)

_CREATEUSERRESPONSE.fields_by_name['user'].message_type = _USER
_USERSRESPONSE.fields_by_name['users'].message_type = _USER
_STORAGEINFORESPONSE.fields_by_name['storage_info'].message_type = powergate_dot_user_dot_v1_dot_user__pb2._STORAGEINFO
_LISTSTORAGEINFORESPONSE.fields_by_name['storage_info'].message_type = powergate_dot_user_dot_v1_dot_user__pb2._STORAGEINFO
_LISTSTORAGEJOBSREQUEST.fields_by_name['selector'].enum_type = powergate_dot_user_dot_v1_dot_user__pb2._STORAGEJOBSSELECTOR
_LISTSTORAGEJOBSRESPONSE.fields_by_name['storage_jobs'].message_type = powergate_dot_user_dot_v1_dot_user__pb2._STORAGEJOB
_PINNEDCIDSRESPONSE.fields_by_name['cids'].message_type = _HSPINNEDCID
_HSPINNEDCID.fields_by_name['users'].message_type = _HSPINNEDCIDUSER
_GETUPDATEDSTORAGEDEALRECORDSSINCEREQUEST.fields_by_name['since'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETUPDATEDSTORAGEDEALRECORDSSINCERESPONSE.fields_by_name['records'].message_type = powergate_dot_user_dot_v1_dot_user__pb2._STORAGEDEALRECORD
_GETUPDATEDRETRIEVALRECORDSSINCEREQUEST.fields_by_name['since'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETUPDATEDRETRIEVALRECORDSSINCERESPONSE.fields_by_name['records'].message_type = powergate_dot_user_dot_v1_dot_user__pb2._RETRIEVALDEALRECORD
_GETMINERSRESPONSE.fields_by_name['miners'].message_type = _FILECOINMINER
_GETMINERINFORESPONSE.fields_by_name['miners_info'].message_type = _MINERINFO
DESCRIPTOR.message_types_by_name['NewAddressRequest'] = _NEWADDRESSREQUEST
DESCRIPTOR.message_types_by_name['NewAddressResponse'] = _NEWADDRESSRESPONSE
DESCRIPTOR.message_types_by_name['AddressesRequest'] = _ADDRESSESREQUEST
DESCRIPTOR.message_types_by_name['AddressesResponse'] = _ADDRESSESRESPONSE
DESCRIPTOR.message_types_by_name['SendFilRequest'] = _SENDFILREQUEST
DESCRIPTOR.message_types_by_name['SendFilResponse'] = _SENDFILRESPONSE
DESCRIPTOR.message_types_by_name['User'] = _USER
DESCRIPTOR.message_types_by_name['CreateUserRequest'] = _CREATEUSERREQUEST
DESCRIPTOR.message_types_by_name['CreateUserResponse'] = _CREATEUSERRESPONSE
DESCRIPTOR.message_types_by_name['RegenerateAuthRequest'] = _REGENERATEAUTHREQUEST
DESCRIPTOR.message_types_by_name['RegenerateAuthResponse'] = _REGENERATEAUTHRESPONSE
DESCRIPTOR.message_types_by_name['UsersRequest'] = _USERSREQUEST
DESCRIPTOR.message_types_by_name['UsersResponse'] = _USERSRESPONSE
DESCRIPTOR.message_types_by_name['StorageInfoRequest'] = _STORAGEINFOREQUEST
DESCRIPTOR.message_types_by_name['StorageInfoResponse'] = _STORAGEINFORESPONSE
DESCRIPTOR.message_types_by_name['ListStorageInfoRequest'] = _LISTSTORAGEINFOREQUEST
DESCRIPTOR.message_types_by_name['ListStorageInfoResponse'] = _LISTSTORAGEINFORESPONSE
DESCRIPTOR.message_types_by_name['ListStorageJobsRequest'] = _LISTSTORAGEJOBSREQUEST
DESCRIPTOR.message_types_by_name['ListStorageJobsResponse'] = _LISTSTORAGEJOBSRESPONSE
DESCRIPTOR.message_types_by_name['StorageJobsSummaryRequest'] = _STORAGEJOBSSUMMARYREQUEST
DESCRIPTOR.message_types_by_name['StorageJobsSummaryResponse'] = _STORAGEJOBSSUMMARYRESPONSE
DESCRIPTOR.message_types_by_name['GCStagedRequest'] = _GCSTAGEDREQUEST
DESCRIPTOR.message_types_by_name['GCStagedResponse'] = _GCSTAGEDRESPONSE
DESCRIPTOR.message_types_by_name['PinnedCidsRequest'] = _PINNEDCIDSREQUEST
DESCRIPTOR.message_types_by_name['PinnedCidsResponse'] = _PINNEDCIDSRESPONSE
DESCRIPTOR.message_types_by_name['HSPinnedCid'] = _HSPINNEDCID
DESCRIPTOR.message_types_by_name['HSPinnedCidUser'] = _HSPINNEDCIDUSER
DESCRIPTOR.message_types_by_name['GetUpdatedStorageDealRecordsSinceRequest'] = _GETUPDATEDSTORAGEDEALRECORDSSINCEREQUEST
DESCRIPTOR.message_types_by_name['GetUpdatedStorageDealRecordsSinceResponse'] = _GETUPDATEDSTORAGEDEALRECORDSSINCERESPONSE
DESCRIPTOR.message_types_by_name['GetUpdatedRetrievalRecordsSinceRequest'] = _GETUPDATEDRETRIEVALRECORDSSINCEREQUEST
DESCRIPTOR.message_types_by_name['GetUpdatedRetrievalRecordsSinceResponse'] = _GETUPDATEDRETRIEVALRECORDSSINCERESPONSE
DESCRIPTOR.message_types_by_name['GetMinersRequest'] = _GETMINERSREQUEST
DESCRIPTOR.message_types_by_name['GetMinersResponse'] = _GETMINERSRESPONSE
DESCRIPTOR.message_types_by_name['FilecoinMiner'] = _FILECOINMINER
DESCRIPTOR.message_types_by_name['GetMinerInfoRequest'] = _GETMINERINFOREQUEST
DESCRIPTOR.message_types_by_name['GetMinerInfoResponse'] = _GETMINERINFORESPONSE
DESCRIPTOR.message_types_by_name['MinerInfo'] = _MINERINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NewAddressRequest = _reflection.GeneratedProtocolMessageType('NewAddressRequest', (_message.Message,), {
  'DESCRIPTOR' : _NEWADDRESSREQUEST,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.NewAddressRequest)
  })
_sym_db.RegisterMessage(NewAddressRequest)

NewAddressResponse = _reflection.GeneratedProtocolMessageType('NewAddressResponse', (_message.Message,), {
  'DESCRIPTOR' : _NEWADDRESSRESPONSE,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.NewAddressResponse)
  })
_sym_db.RegisterMessage(NewAddressResponse)

AddressesRequest = _reflection.GeneratedProtocolMessageType('AddressesRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDRESSESREQUEST,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.AddressesRequest)
  })
_sym_db.RegisterMessage(AddressesRequest)

AddressesResponse = _reflection.GeneratedProtocolMessageType('AddressesResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADDRESSESRESPONSE,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.AddressesResponse)
  })
_sym_db.RegisterMessage(AddressesResponse)

SendFilRequest = _reflection.GeneratedProtocolMessageType('SendFilRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENDFILREQUEST,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.SendFilRequest)
  })
_sym_db.RegisterMessage(SendFilRequest)

SendFilResponse = _reflection.GeneratedProtocolMessageType('SendFilResponse', (_message.Message,), {
  'DESCRIPTOR' : _SENDFILRESPONSE,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.SendFilResponse)
  })
_sym_db.RegisterMessage(SendFilResponse)

User = _reflection.GeneratedProtocolMessageType('User', (_message.Message,), {
  'DESCRIPTOR' : _USER,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.User)
  })
_sym_db.RegisterMessage(User)

CreateUserRequest = _reflection.GeneratedProtocolMessageType('CreateUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUSERREQUEST,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.CreateUserRequest)
  })
_sym_db.RegisterMessage(CreateUserRequest)

CreateUserResponse = _reflection.GeneratedProtocolMessageType('CreateUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUSERRESPONSE,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.CreateUserResponse)
  })
_sym_db.RegisterMessage(CreateUserResponse)

RegenerateAuthRequest = _reflection.GeneratedProtocolMessageType('RegenerateAuthRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGENERATEAUTHREQUEST,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.RegenerateAuthRequest)
  })
_sym_db.RegisterMessage(RegenerateAuthRequest)

RegenerateAuthResponse = _reflection.GeneratedProtocolMessageType('RegenerateAuthResponse', (_message.Message,), {
  'DESCRIPTOR' : _REGENERATEAUTHRESPONSE,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.RegenerateAuthResponse)
  })
_sym_db.RegisterMessage(RegenerateAuthResponse)

UsersRequest = _reflection.GeneratedProtocolMessageType('UsersRequest', (_message.Message,), {
  'DESCRIPTOR' : _USERSREQUEST,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.UsersRequest)
  })
_sym_db.RegisterMessage(UsersRequest)

UsersResponse = _reflection.GeneratedProtocolMessageType('UsersResponse', (_message.Message,), {
  'DESCRIPTOR' : _USERSRESPONSE,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.UsersResponse)
  })
_sym_db.RegisterMessage(UsersResponse)

StorageInfoRequest = _reflection.GeneratedProtocolMessageType('StorageInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEINFOREQUEST,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.StorageInfoRequest)
  })
_sym_db.RegisterMessage(StorageInfoRequest)

StorageInfoResponse = _reflection.GeneratedProtocolMessageType('StorageInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEINFORESPONSE,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.StorageInfoResponse)
  })
_sym_db.RegisterMessage(StorageInfoResponse)

ListStorageInfoRequest = _reflection.GeneratedProtocolMessageType('ListStorageInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTORAGEINFOREQUEST,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.ListStorageInfoRequest)
  })
_sym_db.RegisterMessage(ListStorageInfoRequest)

ListStorageInfoResponse = _reflection.GeneratedProtocolMessageType('ListStorageInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTORAGEINFORESPONSE,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.ListStorageInfoResponse)
  })
_sym_db.RegisterMessage(ListStorageInfoResponse)

ListStorageJobsRequest = _reflection.GeneratedProtocolMessageType('ListStorageJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTORAGEJOBSREQUEST,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.ListStorageJobsRequest)
  })
_sym_db.RegisterMessage(ListStorageJobsRequest)

ListStorageJobsResponse = _reflection.GeneratedProtocolMessageType('ListStorageJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTORAGEJOBSRESPONSE,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.ListStorageJobsResponse)
  })
_sym_db.RegisterMessage(ListStorageJobsResponse)

StorageJobsSummaryRequest = _reflection.GeneratedProtocolMessageType('StorageJobsSummaryRequest', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEJOBSSUMMARYREQUEST,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.StorageJobsSummaryRequest)
  })
_sym_db.RegisterMessage(StorageJobsSummaryRequest)

StorageJobsSummaryResponse = _reflection.GeneratedProtocolMessageType('StorageJobsSummaryResponse', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEJOBSSUMMARYRESPONSE,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.StorageJobsSummaryResponse)
  })
_sym_db.RegisterMessage(StorageJobsSummaryResponse)

GCStagedRequest = _reflection.GeneratedProtocolMessageType('GCStagedRequest', (_message.Message,), {
  'DESCRIPTOR' : _GCSTAGEDREQUEST,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.GCStagedRequest)
  })
_sym_db.RegisterMessage(GCStagedRequest)

GCStagedResponse = _reflection.GeneratedProtocolMessageType('GCStagedResponse', (_message.Message,), {
  'DESCRIPTOR' : _GCSTAGEDRESPONSE,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.GCStagedResponse)
  })
_sym_db.RegisterMessage(GCStagedResponse)

PinnedCidsRequest = _reflection.GeneratedProtocolMessageType('PinnedCidsRequest', (_message.Message,), {
  'DESCRIPTOR' : _PINNEDCIDSREQUEST,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.PinnedCidsRequest)
  })
_sym_db.RegisterMessage(PinnedCidsRequest)

PinnedCidsResponse = _reflection.GeneratedProtocolMessageType('PinnedCidsResponse', (_message.Message,), {
  'DESCRIPTOR' : _PINNEDCIDSRESPONSE,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.PinnedCidsResponse)
  })
_sym_db.RegisterMessage(PinnedCidsResponse)

HSPinnedCid = _reflection.GeneratedProtocolMessageType('HSPinnedCid', (_message.Message,), {
  'DESCRIPTOR' : _HSPINNEDCID,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.HSPinnedCid)
  })
_sym_db.RegisterMessage(HSPinnedCid)

HSPinnedCidUser = _reflection.GeneratedProtocolMessageType('HSPinnedCidUser', (_message.Message,), {
  'DESCRIPTOR' : _HSPINNEDCIDUSER,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.HSPinnedCidUser)
  })
_sym_db.RegisterMessage(HSPinnedCidUser)

GetUpdatedStorageDealRecordsSinceRequest = _reflection.GeneratedProtocolMessageType('GetUpdatedStorageDealRecordsSinceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETUPDATEDSTORAGEDEALRECORDSSINCEREQUEST,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.GetUpdatedStorageDealRecordsSinceRequest)
  })
_sym_db.RegisterMessage(GetUpdatedStorageDealRecordsSinceRequest)

GetUpdatedStorageDealRecordsSinceResponse = _reflection.GeneratedProtocolMessageType('GetUpdatedStorageDealRecordsSinceResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETUPDATEDSTORAGEDEALRECORDSSINCERESPONSE,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.GetUpdatedStorageDealRecordsSinceResponse)
  })
_sym_db.RegisterMessage(GetUpdatedStorageDealRecordsSinceResponse)

GetUpdatedRetrievalRecordsSinceRequest = _reflection.GeneratedProtocolMessageType('GetUpdatedRetrievalRecordsSinceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETUPDATEDRETRIEVALRECORDSSINCEREQUEST,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.GetUpdatedRetrievalRecordsSinceRequest)
  })
_sym_db.RegisterMessage(GetUpdatedRetrievalRecordsSinceRequest)

GetUpdatedRetrievalRecordsSinceResponse = _reflection.GeneratedProtocolMessageType('GetUpdatedRetrievalRecordsSinceResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETUPDATEDRETRIEVALRECORDSSINCERESPONSE,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.GetUpdatedRetrievalRecordsSinceResponse)
  })
_sym_db.RegisterMessage(GetUpdatedRetrievalRecordsSinceResponse)

GetMinersRequest = _reflection.GeneratedProtocolMessageType('GetMinersRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMINERSREQUEST,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.GetMinersRequest)
  })
_sym_db.RegisterMessage(GetMinersRequest)

GetMinersResponse = _reflection.GeneratedProtocolMessageType('GetMinersResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMINERSRESPONSE,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.GetMinersResponse)
  })
_sym_db.RegisterMessage(GetMinersResponse)

FilecoinMiner = _reflection.GeneratedProtocolMessageType('FilecoinMiner', (_message.Message,), {
  'DESCRIPTOR' : _FILECOINMINER,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.FilecoinMiner)
  })
_sym_db.RegisterMessage(FilecoinMiner)

GetMinerInfoRequest = _reflection.GeneratedProtocolMessageType('GetMinerInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMINERINFOREQUEST,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.GetMinerInfoRequest)
  })
_sym_db.RegisterMessage(GetMinerInfoRequest)

GetMinerInfoResponse = _reflection.GeneratedProtocolMessageType('GetMinerInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMINERINFORESPONSE,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.GetMinerInfoResponse)
  })
_sym_db.RegisterMessage(GetMinerInfoResponse)

MinerInfo = _reflection.GeneratedProtocolMessageType('MinerInfo', (_message.Message,), {
  'DESCRIPTOR' : _MINERINFO,
  '__module__' : 'powergate.admin.v1.admin_pb2'
  # @@protoc_insertion_point(class_scope:powergate.admin.v1.MinerInfo)
  })
_sym_db.RegisterMessage(MinerInfo)


DESCRIPTOR._options = None

_ADMINSERVICE = _descriptor.ServiceDescriptor(
  name='AdminService',
  full_name='powergate.admin.v1.AdminService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2608,
  serialized_end=4315,
  methods=[
  _descriptor.MethodDescriptor(
    name='NewAddress',
    full_name='powergate.admin.v1.AdminService.NewAddress',
    index=0,
    containing_service=None,
    input_type=_NEWADDRESSREQUEST,
    output_type=_NEWADDRESSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Addresses',
    full_name='powergate.admin.v1.AdminService.Addresses',
    index=1,
    containing_service=None,
    input_type=_ADDRESSESREQUEST,
    output_type=_ADDRESSESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendFil',
    full_name='powergate.admin.v1.AdminService.SendFil',
    index=2,
    containing_service=None,
    input_type=_SENDFILREQUEST,
    output_type=_SENDFILRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateUser',
    full_name='powergate.admin.v1.AdminService.CreateUser',
    index=3,
    containing_service=None,
    input_type=_CREATEUSERREQUEST,
    output_type=_CREATEUSERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RegenerateAuth',
    full_name='powergate.admin.v1.AdminService.RegenerateAuth',
    index=4,
    containing_service=None,
    input_type=_REGENERATEAUTHREQUEST,
    output_type=_REGENERATEAUTHRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Users',
    full_name='powergate.admin.v1.AdminService.Users',
    index=5,
    containing_service=None,
    input_type=_USERSREQUEST,
    output_type=_USERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StorageInfo',
    full_name='powergate.admin.v1.AdminService.StorageInfo',
    index=6,
    containing_service=None,
    input_type=_STORAGEINFOREQUEST,
    output_type=_STORAGEINFORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListStorageInfo',
    full_name='powergate.admin.v1.AdminService.ListStorageInfo',
    index=7,
    containing_service=None,
    input_type=_LISTSTORAGEINFOREQUEST,
    output_type=_LISTSTORAGEINFORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListStorageJobs',
    full_name='powergate.admin.v1.AdminService.ListStorageJobs',
    index=8,
    containing_service=None,
    input_type=_LISTSTORAGEJOBSREQUEST,
    output_type=_LISTSTORAGEJOBSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StorageJobsSummary',
    full_name='powergate.admin.v1.AdminService.StorageJobsSummary',
    index=9,
    containing_service=None,
    input_type=_STORAGEJOBSSUMMARYREQUEST,
    output_type=_STORAGEJOBSSUMMARYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetUpdatedStorageDealRecordsSince',
    full_name='powergate.admin.v1.AdminService.GetUpdatedStorageDealRecordsSince',
    index=10,
    containing_service=None,
    input_type=_GETUPDATEDSTORAGEDEALRECORDSSINCEREQUEST,
    output_type=_GETUPDATEDSTORAGEDEALRECORDSSINCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetUpdatedRetrievalRecordsSince',
    full_name='powergate.admin.v1.AdminService.GetUpdatedRetrievalRecordsSince',
    index=11,
    containing_service=None,
    input_type=_GETUPDATEDRETRIEVALRECORDSSINCEREQUEST,
    output_type=_GETUPDATEDRETRIEVALRECORDSSINCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GCStaged',
    full_name='powergate.admin.v1.AdminService.GCStaged',
    index=12,
    containing_service=None,
    input_type=_GCSTAGEDREQUEST,
    output_type=_GCSTAGEDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PinnedCids',
    full_name='powergate.admin.v1.AdminService.PinnedCids',
    index=13,
    containing_service=None,
    input_type=_PINNEDCIDSREQUEST,
    output_type=_PINNEDCIDSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetMiners',
    full_name='powergate.admin.v1.AdminService.GetMiners',
    index=14,
    containing_service=None,
    input_type=_GETMINERSREQUEST,
    output_type=_GETMINERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetMinerInfo',
    full_name='powergate.admin.v1.AdminService.GetMinerInfo',
    index=15,
    containing_service=None,
    input_type=_GETMINERINFOREQUEST,
    output_type=_GETMINERINFORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ADMINSERVICE)

DESCRIPTOR.services_by_name['AdminService'] = _ADMINSERVICE

# @@protoc_insertion_point(module_scope)
